@@ -14,7 +14,7 @@ import static io.cucumber.gherkin.Token.createGherkinLine;
  * creates a token for each line. The tokens are passed to the parser, which
  * outputs an AST (Abstract Syntax Tree).</p>
  */
-class TokenScanner {
+final class TokenScanner {
 
     private final BufferedReader reader;
     private int lineNumber;
