@@ -87,7 +87,9 @@ class GherkinDocumentBuilderTest {
                 "      |a||b|",
                 "test.feature"
         );
-        TableRow row = doc.getFeature().get().getChildren().get(0).getScenario().get().getSteps().get(0).getDataTable().get().getRows().get(0);
+        List<FeatureChild> children = doc.getFeature().get().getChildren();
+        assertEquals(1, children.size());
+        TableRow row = children.get(0).getScenario().get().getSteps().get(0).getDataTable().get().getRows().get(0);
         assertEquals("a", row.getCells().get(0).getValue());
         assertEquals("", row.getCells().get(1).getValue());
         assertEquals("b", row.getCells().get(2).getValue());
